@@ -43,6 +43,7 @@ class McModel(object):
 
     @classmethod
     def mc_get_multi(cls, id_list):
+        id_list = tuple(id_list)
         mc_key = cls.Meta.mc_key
         result = mc.get_multi([mc_key%i for i in id_list])
         r = {}
@@ -61,8 +62,9 @@ class McModel(object):
 
     @classmethod
     def mc_get_list(cls, id_list):
+        id_list = tuple(id_list)
         mc_key = cls.Meta.mc_key
-        result = mc.get_multi([mc_key%i for i in id_list])
+        result = mc.get_multi(mc_key%i for i in id_list)
         r = []
         for i in id_list:
             t = result.get(mc_key%i)
@@ -75,6 +77,7 @@ class McModel(object):
                 t = cls(*t)
                 t._new_record = False
             r.append(t)
+        
         return r
 
 
